@@ -1,27 +1,33 @@
-/* Copyright (C) by GFD-Dennou Club, 1999-2000.  All rights reserved. */
-/* slrat.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
 static integer c__1 = 1;
 
+/* ----------------------------------------------------------------------- */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int slrat_(real *rx, real *ry)
 {
-    static real arat, brat, xamin, yamin, xamax, yamax;
-    extern /* Subroutine */ int slmgn_(real *, real *, real *, real *);
-    static real xx;
-    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen);
-    static real yy;
-    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
-	    ftnlen, ftnlen), slqrct_(integer *, integer *, real *, real *, 
-	    real *, real *);
+    static real xx, yy;
     static integer lev;
+    static real arat, brat, xamin, yamin, xamax, yamax;
+    extern /* Subroutine */ int slmgn_(real *, real *, real *, real *), 
+	    sgiget_(char *, integer *, ftnlen), msgdmp_(char *, char *, char *
+	    , ftnlen, ftnlen, ftnlen), slqrct_(integer *, integer *, real *, 
+	    real *, real *, real *);
 
     if (*rx < 0.f || *ry < 0.f) {
 	msgdmp_("E", "SLRAT ", "PROPORTION PARAMETER IS LESS THAN ZERO.", (
