@@ -33,13 +33,13 @@ struct {
 
 static logical c_true = TRUE_;
 static integer c__92 = 92;
-static integer c__1 = 1;
-static integer c__3 = 3;
+static integer c__180 = 180;
+static integer c__182 = 182;
 
 /* ----------------------------------------------------------------------- */
 /*     BASIC TEXT PRIMITIVE ON VC */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int sztxwv_(real *vx, real *vy, char *chars, ftnlen 
 	chars_len)
@@ -49,32 +49,25 @@ static integer c__3 = 3;
     static integer ncntz = 0;
 
     /* System generated locals */
-    address a__1[3];
-    integer i__1, i__2, i__3[3];
+    integer i__1, i__2;
     real r__1;
-    char ch__1[1], ch__2[83];
-    icilist ici__1;
+    char ch__1[1];
 
     /* Builtin functions */
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
     double asin(doublereal);
-    integer s_wsfi(icilist *), do_fio(integer *, char *, ftnlen), e_wsfi(void)
-	    ;
-    /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
     /* Local variables */
     static char fontname[70];
-    static logical markfont;
-    static integer k, n, nc, ip;
+    static integer i__, j, k, n, nc, ip;
     static real xc, yc;
-    static integer np, nx, ny;
-    static real xp, yp, wx, wy, vx1, wx1[256], wx2[256], vx2;
+    static integer nx, ny;
+    static real xp, yp, wx, wy, vx1, wx1[2048], wx2[2048], vx2;
     static integer idx;
     static char ckx[1*6000], cky[1*6000];
-    static integer icz, ncz, ips;
+    static integer ncz, ips;
     static real fnx, fny;
     static integer idx0;
-    static char cobj[80], cbuf[80];
     extern integer lenc_(char *, ftnlen);
     static integer mode;
     extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
@@ -86,44 +79,56 @@ static integer c__3 = 3;
     static real wxch;
     static char csup[1], crst[1];
     static real wych;
-    static integer isup, irst, mode0;
-    extern /* Subroutine */ int cdblk_(char *, ftnlen);
-    static integer imode;
+    static integer isup, irst, mode0, imode;
+    static char charx[2048];
     static logical lmark;
     static integer index, idest;
-    static char charz[256];
+    static char charz[2048];
     static real factz, irota;
     static integer ifont;
     static real xrate, yrate;
-    static integer nskip;
-    static real rxmin, rymin, rxmax, rymax;
-    static integer iwtrf, iposx[256];
+    static integer nskip, isubz;
+    static real rxmin, rxmax, rymin, rymax;
+    static integer iposx[2048];
     static real wxmin, wxmax, wymin, wymax;
+    static integer iwtrf, isupz, irstz;
     extern /* Subroutine */ int swsfw_(integer *), swtxt_(real *, real *, 
-	    real *, char *, integer *, real *, integer *, ftnlen), sgiget_(
-	    char *, integer *, ftnlen), sglget_(char *, logical *, ftnlen), 
-	    msgdmp_(char *, char *, char *, ftnlen, ftnlen, ftnlen), swcget_(
-	    char *, char *, ftnlen, ftnlen), swftfc_(char *, ftnlen);
+	    real *, char *, integer *, real *, integer *, ftnlen);
+    static integer iocmde, iocmod;
+    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), sglget_(
+	    char *, logical *, ftnlen), msgdmp_(char *, char *, char *, 
+	    ftnlen, ftnlen, ftnlen), swcget_(char *, char *, ftnlen, ftnlen), 
+	    swftfc_(char *, ftnlen);
     static logical lfprop;
     extern /* Subroutine */ int swscli_(integer *, logical *), swlget_(char *,
-	     logical *, ftnlen), swocls_(char *, ftnlen), szfint_(integer *), 
+	     logical *, ftnlen);
+    static logical lcntlz;
+    extern /* Subroutine */ int swocls_(char *, ftnlen), szfint_(integer *), 
 	    szqidx_(integer *), szclsv_(void), szqfnt_(integer *, char *, 
-	    char *, ftnlen, ftnlen), swoopn_(char *, char *, ftnlen, ftnlen), 
-	    szqfnw_(real *, real *), stfwtr_(real *, real *, real *, real *), 
-	    szplsv_(real *, real *), stqwtr_(real *, real *, real *, real *, 
-	    real *, real *, real *, real *, integer *), szopsv_(void), 
-	    szmvsv_(real *, real *), szqtxw_(char *, integer *, real *, real *
-	    , ftnlen);
-    static logical sysfont;
-
-    /* Fortran I/O blocks */
-    static icilist io___50 = { 0, cobj, 0, "(2I8)", 80, 1 };
-
+	    char *, ftnlen, ftnlen), szqfnw_(real *, real *), stfwtr_(real *, 
+	    real *, real *, real *), szplsv_(real *, real *), stqwtr_(real *, 
+	    real *, real *, real *, real *, real *, real *, real *, integer *)
+	    , szopsv_(void), szmvsv_(real *, real *), szqtxw_(char *, integer 
+	    *, real *, real *, ftnlen);
+    static logical lmrkfnt, lsysfnt;
 
+    lcntlz = szbtx2_1.lcntl;
+    sgiget_("ISUP", &isup, (ftnlen)4);
+    sgiget_("ISUB", &isub, (ftnlen)4);
+    sgiget_("IRST", &irst, (ftnlen)4);
+    isupz = 29;
+    isubz = 30;
+    irstz = 31;
+    csgi_(ch__1, (ftnlen)1, &isupz);
+    *(unsigned char *)csup = *(unsigned char *)&ch__1[0];
+    csgi_(ch__1, (ftnlen)1, &isubz);
+    *(unsigned char *)csub = *(unsigned char *)&ch__1[0];
+    csgi_(ch__1, (ftnlen)1, &irstz);
+    *(unsigned char *)crst = *(unsigned char *)&ch__1[0];
 /*      / START: CODE FOR USING SYSTEN FONTS / */
 /*      / PROCCESS IF NOT MARKER / */
-    swlget_("SYSFONT", &sysfont, (ftnlen)7);
-    if (sysfont) {
+    swlget_("LSYSFNT", &lsysfnt, (ftnlen)7);
+    if (lsysfnt) {
 	szqidx_(&index);
 	swcget_("FONTNAME", fontname, (ftnlen)8, (ftnlen)70);
 /*     / WHEN FONTNAME IS NOT GIVEN / */
@@ -148,8 +153,8 @@ static integer c__3 = 3;
 	    swftfc_(fontname, (ftnlen)70);
 	}
 	idx = isgc_(chars, (ftnlen)1);
-	sglget_("MARKFONT", &markfont, (ftnlen)8);
-	if (idx > 18 || markfont) {
+	sglget_("LMRKFNT", &lmrkfnt, (ftnlen)7);
+	if (idx > 18 || lmrkfnt) {
 	    ncz = lenc_(chars, chars_len);
 	    stfwtr_(vx, vy, &wx, &wy);
 	    stqwtr_(&rxmin, &rxmax, &rymin, &rymax, &wxmin, &wxmax, &wymin, &
@@ -181,43 +186,80 @@ static integer c__3 = 3;
 	szqfnw_(wx1, wx2);
 	ncntz = ncnt;
     }
-/*     / CONVERT NEW TYPE MARKUPS TO OLD ONE / */
+/*     /REMOVE DCL EXT CHARACTER MARKER +/ */
     ncz = lenc_(chars, chars_len);
-    for (n = 1; n <= 256; ++n) {
-	s_copy(charz, " ", (ftnlen)256, (ftnlen)1);
+    j = 0;
+    i__1 = ncz;
+    for (i__ = 1; i__ <= i__1; ++i__) {
+	idx0 = isgc_(chars + (i__ - 1), (ftnlen)1);
+	if (idx0 == 92) {
+	    imode = 1;
+	}
+	if (imode == 0 || imode == 4) {
+	    ++j;
+	    *(unsigned char *)&charx[j - 1] = *(unsigned char *)&chars[i__ - 
+		    1];
+	    imode = 0;
+	}
+	if (imode == 3) {
+	    if (idx0 == 120) {
+		imode = 2;
+	    } else {
+		++j;
+		csgi_(ch__1, (ftnlen)1, &c__92);
+		*(unsigned char *)&charx[j - 1] = *(unsigned char *)&ch__1[0];
+		++j;
+		*(unsigned char *)&charx[j - 1] = *(unsigned char *)&chars[
+			i__ - 1];
+		imode = 0;
+	    }
+	}
+	if (imode == 1 || imode == 2) {
+	    imode += 2;
+	}
+/* L999: */
+    }
+    for (i__ = j + 1; i__ <= 2048; ++i__) {
+	*(unsigned char *)&charx[i__ - 1] = '\0';
+/* L998: */
+    }
+/*     / CONVERT NEW TYPE MARKUPS TO OLD ONE / */
+    ncz = lenc_(charx, (ftnlen)2048);
+    for (n = 1; n <= 2048; ++n) {
+	s_copy(charz, " ", (ftnlen)2048, (ftnlen)1);
 /* L1: */
     }
-    sgiget_("ISUP", &isup, (ftnlen)4);
-    sgiget_("ISUB", &isub, (ftnlen)4);
-    sgiget_("IRST", &irst, (ftnlen)4);
-    csgi_(ch__1, (ftnlen)1, &isup);
-    *(unsigned char *)csup = *(unsigned char *)&ch__1[0];
-    csgi_(ch__1, (ftnlen)1, &isub);
-    *(unsigned char *)csub = *(unsigned char *)&ch__1[0];
-    csgi_(ch__1, (ftnlen)1, &irst);
-    *(unsigned char *)crst = *(unsigned char *)&ch__1[0];
     nskip = 0;
     idest = 1;
     imode = 0;
+    iocmde = 0;
     lmark = TRUE_;
     i__1 = ncz;
     for (n = 1; n <= i__1; ++n) {
-	idx0 = isgc_(chars + (n - 1), (ftnlen)1);
+	idx0 = isgc_(charx + (n - 1), (ftnlen)1);
 	if (imode == 1) {
 	    if (idx0 == 94) {
+		lcntlz = TRUE_;
 		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)csup;
 		++idest;
 	    } else if (idx0 == 95) {
+		lcntlz = TRUE_;
 		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)csub;
 		++idest;
 	    } else if (idx0 == 111) {
-		*(unsigned char *)&charz[idest - 1] = '~';
+/*           180: UP ARROW */
+		csgi_(ch__1, (ftnlen)1, &c__180);
+		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)&
+			ch__1[0];
 		++idest;
 		msgdmp_("W", "SZTXWV", "TOPBAR IS NOT SUPPORT IN STROKEFONT", 
 			(ftnlen)1, (ftnlen)6, (ftnlen)35);
 		lmark = FALSE_;
 	    } else if (idx0 == 117) {
-		*(unsigned char *)&charz[idest - 1] = '~';
+/*           182: DOWN ARROW */
+		csgi_(ch__1, (ftnlen)1, &c__182);
+		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)&
+			ch__1[0];
 		++idest;
 		msgdmp_("W", "SZTXWV", "UNDERBAR IS NOT SUPPORT IN STROKEFONT"
 			, (ftnlen)1, (ftnlen)6, (ftnlen)37);
@@ -233,7 +275,7 @@ static integer c__3 = 3;
 	    } else {
 		imode = 0;
 		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)&
-			chars[n - 1];
+			charx[n - 1];
 		++idest;
 		if (lmark) {
 		    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)
@@ -244,7 +286,7 @@ static integer c__3 = 3;
 		}
 	    }
 	} else if (imode == 2) {
-	    if (isgc_(chars + (n - 1), (ftnlen)1) == 125) {
+	    if (isgc_(charx + (n - 1), (ftnlen)1) == 125) {
 		imode = 0;
 		if (lmark) {
 		    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)
@@ -255,81 +297,55 @@ static integer c__3 = 3;
 		}
 	    } else {
 		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)&
-			chars[n - 1];
+			charx[n - 1];
 		++idest;
 	    }
 /*       92:\ 94:^ 95:_ 111:o 117:u 123:{ 125:} */
 	} else if (idx0 == 92) {
 	    imode = 1;
+/* OLD TYPE CONTROL */
+	} else if (idx0 == isup && szbtx2_1.lcntl) {
+	    csgi_(ch__1, (ftnlen)1, &isup);
+	    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)&ch__1[0];
+	    iocmde = idest;
+	    ++idest;
+	} else if (idx0 == isub && szbtx2_1.lcntl) {
+	    csgi_(ch__1, (ftnlen)1, &isub);
+	    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)&ch__1[0];
+	    iocmde = -idest;
+	    ++idest;
+	} else if (idx0 == irst && szbtx2_1.lcntl) {
+	    if (iocmde > 0) {
+		*(unsigned char *)&charz[iocmde - 1] = *(unsigned char *)csup;
+		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)crst;
+		++idest;
+		iocmod = 0;
+	    } else if (iocmde < 0) {
+		i__2 = -iocmde - 1;
+		s_copy(charz + i__2, csub, -iocmde - i__2, (ftnlen)1);
+		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)crst;
+		++idest;
+		iocmod = 0;
+	    } else {
+		csgi_(ch__1, (ftnlen)1, &irst);
+		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)&
+			ch__1[0];
+		iocmde = 0;
+		++idest;
+	    }
 	} else {
-	    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)&chars[n 
+	    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)&charx[n 
 		    - 1];
 	    ++idest;
 	}
 /* L3: */
     }
-    if (imode != 0) {
-	if (idest <= ncz) {
-	    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)crst;
-	    ++idest;
-	}
-	msgdmp_("W", "SZTXWV", "MARKUP IS NOT IN GOOD AGREEMENT.", (ftnlen)1, 
-		(ftnlen)6, (ftnlen)32);
-    }
     if (idest <= ncz) {
 	ncz = idest - 1;
     }
-    szqtxw_(charz, &nc, &wxch, &wych, (ftnlen)256);
-/*     / WRITE INFORMATION FOR PS DRIVER / */
-    stfwtr_(vx, vy, &wx, &wy);
-    s_copy(cbuf, " ", (ftnlen)80, (ftnlen)1);
-    np = 0;
-    i__1 = ncz;
-    for (n = 1; n <= i__1; ++n) {
-	icz = isgc_(charz + (n - 1), (ftnlen)1);
-	++np;
-	if (32 <= icz && icz <= 127 && icz != 37) {
-	    *(unsigned char *)&cbuf[np - 1] = *(unsigned char *)&charz[n - 1];
-	} else {
-	    ici__1.icierr = 0;
-	    ici__1.icirnum = 1;
-	    ici__1.icirlen = 4;
-	    ici__1.iciunit = cbuf + (np - 1);
-	    ici__1.icifmt = "(A,I3.3)";
-	    s_wsfi(&ici__1);
-	    do_fio(&c__1, "%", (ftnlen)1);
-	    do_fio(&c__1, (char *)&icz, (ftnlen)sizeof(integer));
-	    e_wsfi();
-	    np += 3;
-	}
-/* L5: */
-    }
-    s_wsfi(&io___50);
-    i__1 = (integer) wx;
-    do_fio(&c__1, (char *)&i__1, (ftnlen)sizeof(integer));
-    i__2 = (integer) wy;
-    do_fio(&c__1, (char *)&i__2, (ftnlen)sizeof(integer));
-    e_wsfi();
-    cdblk_(cobj, (ftnlen)80);
-    if (lenc_(cbuf, (ftnlen)80) == 80) {
-	msgdmp_("E", "SZTXWV", "STRING LENGTH TOO LONG. CONSIDER USING SYSTE"
-		"M FONT.", (ftnlen)1, (ftnlen)6, (ftnlen)51);
-    }
-    i__1 = lenc_(cobj, (ftnlen)80);
-    ici__1.icierr = 0;
-    ici__1.icirnum = 1;
-    ici__1.icirlen = 80 - i__1;
-    ici__1.iciunit = cobj + i__1;
-    ici__1.icifmt = "(A)";
-    s_wsfi(&ici__1);
-/* Writing concatenation */
-    i__3[0] = 2, a__1[0] = " \"";
-    i__3[1] = np, a__1[1] = cbuf;
-    i__3[2] = 1, a__1[2] = "\"";
-    s_cat(ch__2, a__1, i__3, &c__3, (ftnlen)83);
-    do_fio(&c__1, ch__2, np + 3);
-    e_wsfi();
-    swoopn_("SZTXZ", cobj, (ftnlen)5, (ftnlen)80);
+/*  / END CONVERT MARKUPS / */
+    lcntlz = TRUE_;
+    szqtxw_(charz, &nc, &wxch, &wych, (ftnlen)2048);
 /*     / CALCULATE OFFSET VALUES / */
     offx = wxch * -.5f * 24.f * (szbtx1_1.icentz + 1);
     offy = 0.f;
@@ -345,17 +361,17 @@ static integer c__3 = 3;
     for (k = 1; k <= i__1; ++k) {
 /*       / CHARACTER CONVERSION / */
 	idx = isgc_(charz + (k - 1), (ftnlen)1) + 1;
-	ips = iposx[idx - 1] + 1;
 /*       / CHECK CONTROL CHARACTERS / */
-	if (szbtx2_1.lcntl && (idx == szbtx2_1.jsub || idx == szbtx2_1.jsup ||
-		 idx == szbtx2_1.jrst)) {
-	    if (idx == szbtx2_1.jsub) {
+	ips = iposx[idx - 1] + 1;
+	if (lcntlz && (idx == isubz + 1 || idx == isupz + 1 || idx == irstz + 
+		1)) {
+	    if (idx == isubz + 1) {
 		mode = -1;
 		factz = szbtx2_1.small;
-	    } else if (idx == szbtx2_1.jsup) {
+	    } else if (idx == isupz + 1) {
 		mode = 1;
 		factz = szbtx2_1.small;
-	    } else if (idx == szbtx2_1.jrst) {
+	    } else if (idx == irstz + 1) {
 		mode = 0;
 		factz = 1.f;
 	    }
