@@ -1,29 +1,37 @@
-/* Copyright (C) by GFD-Dennou Club, 1999-2000.  All rights reserved. */
-/* rudlev.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* ----------------------------------------------------------------------- */
 /*     RUDLEV */
 /* ----------------------------------------------------------------------- */
-doublereal rudlev_(integer *nlev)
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
+/* ----------------------------------------------------------------------- */
+real rudlev_(integer *nlev)
 {
     /* System generated locals */
     integer i__1;
     real ret_val;
 
     /* Local variables */
+    static real hl1, hl2;
+    static char clv1[8], clv2[8];
     static integer indx1, indx2;
     static real zlev1, zlev2;
     static integer ityp1, ityp2, nlevz;
     extern /* Subroutine */ int udqcln_(integer *), msgdmp_(char *, char *, 
 	    char *, ftnlen, ftnlen, ftnlen), udqclv_(real *, integer *, 
 	    integer *, char *, real *, integer *, ftnlen);
-    static real hl1, hl2;
-    static char clv1[8], clv2[8];
 
     udqcln_(&nlevz);
     if (! (2 <= nlevz)) {
